==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-jsonpath/src/main/java/org/apache/camel/jsonpath/JsonPathAdapter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.jsonpath;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.Exchange;

public interface JsonPathAdapter {

    /**
     * Initializes the adapter
     *
     * @param camelContext the CamelContext
     */
    void init(CamelContext camelContext);

    /**
     * Attempt to read/convert the message body into a {@link Map} type
     *
     * @param body the message body
     * @param exchange the Camel exchange
     * @return converted as {@link Map} or <tt>null</tt> if not possible
     */
    Map readValue(Object body, Exchange exchange);

    /**
     * Attempts to write the value as a JSOn {@link String} value.
     *
     * @param value  the value
     * @param exchange the Camel exchange
     * @return written as {@link String} JSon or <tt>null</tt> if not possible
     */
    String writeAsString(Object value, Exchange exchange);
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/components/camel-jsonpath/src/main/java/org/apache/camel/jsonpath/JsonPathAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.jsonpath;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.Exchange;

public interface JsonPathAdapter {

    /**
     * Initializes the adapter
     *
     * @param camelContext the CamelContext
     */
    void init(CamelContext camelContext);

    /**
     * Attempt to read/convert the message body into a {@link Map} type
     *
     * @param  body     the message body
     * @param  exchange the Camel exchange
     * @return          converted as {@link Map} or <tt>null</tt> if not possible
     */
    Map readValue(Object body, Exchange exchange);

    /**
     * Attempts to write the value as a JSOn {@link String} value.
     *
     * @param  value    the value
     * @param  exchange the Camel exchange
     * @return          written as {@link String} JSON or <tt>null</tt> if not possible
     */
    String writeAsString(Object value, Exchange exchange);
}
